% Codes for nonparametric analysis - Figures 4, 5, 6 and 7

% Title: Preference and WTP stability for public forest management
% Authors: Mikoaj Czajkowski; Anna Bartczak; Wiktor Budziski; Marek
% Giergiczny; Nick Hanley

% OUTPUT:
% Fig2 contains data depicted in Figure 4
% T contains data depicted in Figure 5
%     Rows correspond to CT number
%     Columns correspond to: Share of unchanged decisions/Share of unchanged SQ decisions/Share of unchanged NSQ decisions/Share of unchanged decisions (cumulatively)/Share of unchanged SQ decisions (cumulatively)/Share of unchanged NSQ decisions (cumulatively)
%     95% confidence intervals were calculated separately and are not included here
% T2 contains data depicted in Figure 6
%     Rows and colums the same as in T1
% T3 contains data depicted in Figure 7
%     Rows and colums the same as in T1
% 
clear all
clc

EstimOpt.fnameinput = ('NEWFOREX_DCE_10.mat'); 
DATA = load(EstimOpt.fnameinput);

%Eff2 mwi jaki design w pierwszym badaniu 0 to O
% Design2 mwi jaki w drugim
DATA.SQ = DATA.ALT == 1;
X = [DATA.SQ DATA.GOS DATA.CEN DATA.VIS==1 DATA.VIS==2 -DATA.FEE];
X = X(DATA.Badanie == 2,:);

X = X(DATA.Eff2(DATA.Badanie == 2) == 0 & DATA.Design2(DATA.Badanie == 2) == 0,:);

XX = reshape(X, 36*3, 193, 6);
XX = permute(XX, [3 1 2]); %faktycznie ta sama kolejno, to na pniej

Y = DATA.RANK == 1;

Y = Y(DATA.Badanie == 2);
YY = reshape(Y, 3, 12, 3, 789);
Y1 = YY(:,:,1,:);
Y1 = permute(Y1, [1 2 4 3]); %odpowiedzi na pierwsze 12 CT
Y2 = YY(:,:,2,:);
Y2 = permute(Y2, [1 2 4 3]); % odpowiedzi na drugie 12 CT
YX = Y1 - Y2; % NALT x NCT x NP
T = zeros(12, 6); % 12 CT w kolumnach: 1) ile % nie zmienio 2) i 3) w rozbiciu na SQ i NSQ, 4), 5) i 6) to samo tyle e skumulowane
YXX = sum(abs(YX),1);
YXX = permute(YXX, [2 3 1]); % 12 x 789 przyjmuje 0 jeeli kto nie zmieni odpowiedzi i 2 jeeli zmieni
T(:,1) = mean(YXX == 0 ,2);
T(:,2) = mean((YXX == 0).*(permute(Y1(1,:,:), [2 3 1]) == 1),2);
T(:,3) = mean((YXX == 0).*(permute(Y1(1,:,:), [2 3 1]) == 0),2);

SQchoose = sum(permute(Y1(1,:,:), [2 3 1]) == 1,2);


% SKUMULOWANE
Ycumul = cumsum(YXX,1);
T(:,4) = mean(Ycumul == 0, 2);
Ycumul2 = cumsum(YXX + (permute(Y1(1,:,:), [2 3 1]) == 0));
T(:,5) = mean(Ycumul2 == 0, 2);
Ycumul3 = cumsum(YXX + (permute(Y1(1,:,:), [2 3 1]) == 1));
T(:,6) = mean(Ycumul3 == 0, 2);

Pic1 = sum(YXX,1)/2; % no. of decision changed
Fig2 = [sum(Pic1 == 0)/789, sum(Pic1 == 1)/789, sum(Pic1 == 2)/789, sum(Pic1 == 3)/789, sum(Pic1 == 4)/789, sum(Pic1 == 5)/789, sum(Pic1 == 6)/789];
Fig2 = [Fig2, sum(Pic1 == 7)/789, sum(Pic1 == 8)/789, sum(Pic1 == 9)/789. sum(Pic1 == 10)/789, sum(Pic1 == 11)/789, sum(Pic1 == 12)/789];

% rednie czasy odpowiedzi

V = [DATA.TIME_1,DATA.TIME_2,DATA.TIME_3,DATA.TIME_4,DATA.TIME_5,DATA.TIME_6,DATA.TIME_7,DATA.TIME_8,DATA.TIME_9,DATA.TIME_10,DATA.TIME_11,DATA.TIME_12];
V = [V, DATA.TIME_13,DATA.TIME_14,DATA.TIME_15,DATA.TIME_16,DATA.TIME_17,DATA.TIME_18,DATA.TIME_19,DATA.TIME_20,DATA.TIME_21,DATA.TIME_22,DATA.TIME_23,DATA.TIME_24];
V = V(DATA.Badanie == 2,:);
V = reshape(V, 108, 789, 12, 2);
VV = permute(V(1,:,:,:), [3 4 2 1]);
%Times = mean(VV, 3);
Times = median(VV, 3);

% Powrt do porwnania z Sample C.
% Porwnanie z A, B oraz z A i B cznie

Z = DATA.RANK == 1;
Z = Z(DATA.Badanie == 2);
Z = Z(DATA.Eff2(DATA.Badanie == 2) == 0 & DATA.Design2(DATA.Badanie == 2) == 0); 
ZZ = reshape(Z, 3, 12, 3, 193);
ZZ1 = permute(ZZ(:,:,1,:), [1 2 4 3]); % 3 x 12 x 193
ZZ2 = permute(ZZ(:,:,2,:), [1 2 4 3]);
ZZ3 = permute(ZZ(:,:,3,:), [1 2 4 3]);
%Porwnanie z A
ZA = ZZ1 - ZZ3;
T2 = zeros(12, 6);
ZAA = sum(abs(ZA),1);
ZAA = permute(ZAA, [2 3 1]);
T2(:,1) = mean(ZAA == 0 ,2);
T2(:,2) = mean((ZAA == 0).*(permute(ZZ1(1,:,:), [2 3 1]) == 1),2);
T2(:,3) = mean((ZAA == 0).*(permute(ZZ1(1,:,:), [2 3 1]) == 0),2);
ZcumulA = cumsum(ZAA,1);
T2(:,4) = mean(ZcumulA == 0, 2);
ZcumulA2 = cumsum(ZAA + (permute(ZZ1(1,:,:), [2 3 1]) == 0));
T2(:,5) = mean(ZcumulA2 == 0, 2);
ZcumulA3 = cumsum(ZAA + (permute(ZZ1(1,:,:), [2 3 1]) == 1));
T2(:,6) = mean(ZcumulA3 == 0, 2);

%Porwnanie z B
ZB = ZZ2 - ZZ3;
T3 = zeros(12, 6);
ZBB = sum(abs(ZB),1);
ZBB = permute(ZBB, [2 3 1]);
T3(:,1) = mean(ZBB == 0 ,2);
T3(:,2) = mean((ZBB == 0).*(permute(ZZ2(1,:,:), [2 3 1]) == 1),2);
T3(:,3) = mean((ZBB == 0).*(permute(ZZ2(1,:,:), [2 3 1]) == 0),2);
ZcumulB2 = cumsum(ZBB,1);
T3(:,4) = mean(ZcumulB2 == 0, 2);
ZcumulB2 = cumsum(ZBB + (permute(ZZ2(1,:,:), [2 3 1]) == 0));
T3(:,5) = mean(ZcumulB2 == 0, 2);
ZcumulB3 = cumsum(ZBB + (permute(ZZ2(1,:,:), [2 3 1]) == 1));
T3(:,6) = mean(ZcumulB3 == 0, 2);

%Porwnanie z A i B cznie

ZAB = ZZ1.*ZZ2.*ZZ3;
T4 = zeros(12,6);
ZABAB = sum(ZAB,1);
ZABAB = permute(ZABAB, [2 3 1]); %12 x 193 tu 0 oznacza, e ktos zmienil odpowiedz
T4(:,1) = mean(ZABAB == 1,2);
T4(:,2) = mean((ZABAB == 1).*(permute(ZZ1(1,:,:), [2 3 1]) == 1),2);
T4(:,3) = mean((ZABAB == 1).*(permute(ZZ1(1,:,:), [2 3 1]) == 0),2);
Zcumul3 = cumsum(ZABAB == 0,1); % tutaj ju 0 oznacza, ze ktos nie zmienil odpowidzi 
T4(:,4) = mean(Zcumul3 == 0 ,2);

% SKUMULOWANE
Zcumul4 = cumsum((ZABAB == 0) + (permute(ZZ1(1,:,:), [2 3 1]) == 0));
T4(:,5) = mean(Zcumul4 == 0, 2);
Zcumul5 = cumsum((ZABAB == 0) + (permute(ZZ1(1,:,:), [2 3 1]) == 1));
T4(:,6) = mean(Zcumul5 == 0, 2);

