% Codes for nonparametric analysis - Figure A1 and Table A1

% Title: Preference and WTP stability for public forest management
% Authors: Mikoaj Czajkowski; Anna Bartczak; Wiktor Budziski; Marek
% Giergiczny; Nick Hanley

% OUTPUT:
% T contains data depicted in Figure A1
%     Rows correspond to CT number
%     Columns correspond to: Share of unchanged decisions/Share of unchanged SQ decisions/Share of unchanged NSQ decisions/Share of unchanged decisions (cumulatively)/Share of unchanged SQ decisions (cumulatively)/Share of unchanged NSQ decisions (cumulatively)
%     95% confidence intervals were calculated separately and are not included here
% KW contains results of Kruskal Wallis tests presented in Table A1
% P provides p-values for KW table

clear all
clc

EstimOpt.fnameinput = ('NEWFOREX_DCE_10.mat'); 
DATA = load(EstimOpt.fnameinput);

%Eff2 mwi jaki design w pierwszym badaniu 0 to O
% Design2 mwi jaki w drugim

Y = DATA.RANK == 1;

Y = Y(DATA.Badanie == 1);


YY = reshape(Y, 3, 12, 3, 211);
Y1 = YY(:,:,1,:);
Y1 = permute(Y1, [1 2 4 3]); %odpowiedzi na pierwsze 12 CT
Y2 = YY(:,:,2,:);
Y2 = permute(Y2, [1 2 4 3]); % odpowiedzi na drugie 12 CT
YX = Y1 - Y2; 
T = zeros(12, 6); % 12 CT w kolumnach: 1) ile % nie zmienio 2) i 3) w rozbiciu na SQ i NSQ, 4), 5) i 6) to samo tyle e skumulowane
YXX = sum(abs(YX),1);
YXX = permute(YXX, [2 3 1]); % 12 x 789 przyjmuje 0 jeeli kto nie zmieni odpowiedzi i 2 jeeli zmieni
T(:,1) = mean(YXX == 0 ,2);
T(:,2) = mean((YXX == 0).*(permute(Y1(1,:,:), [2 3 1]) == 1),2);
T(:,3) = mean((YXX == 0).*(permute(Y1(1,:,:), [2 3 1]) == 0),2);

% SKUMULOWANE
Ycumul = cumsum(YXX,1);
T(:,4) = mean(Ycumul == 0, 2);
Ycumul2 = cumsum(YXX + (permute(Y1(1,:,:), [2 3 1]) == 0));
T(:,5) = mean(Ycumul2 == 0, 2);
Ycumul3 = cumsum(YXX + (permute(Y1(1,:,:), [2 3 1]) == 1));
T(:,6) = mean(Ycumul3 == 0, 2);

Z = DATA.RANK == 1;

Z = Z(DATA.Badanie == 2);


ZZ = reshape(Z, 3, 12, 3, 789);
Z1 = ZZ(:,:,1,:);
Z1 = permute(Z1, [1 2 4 3]); %odpowiedzi na pierwsze 12 CT
Z2 = ZZ(:,:,2,:);
Z2 = permute(Z2, [1 2 4 3]); % odpowiedzi na drugie 12 CT
ZX = Z1 - Z2; 
ZXX = sum(abs(ZX),1);
ZXX = permute(ZXX, [2 3 1]); % 12 x 789 przyjmuje 0 jeeli kto nie zmieni odpowiedzi i 2 jeeli zmieni
KW = zeros(12,3);
P = zeros(12,3);

group = [ones(789,1); 2*ones(211,1)];
for i =1:12
    tmp = [(ZXX(i,:) == 0)'; (YXX(i,:) == 0)'];
    tmp = tmp +0;
    [p, tbl, stats] = kruskalwallis(tmp, group, 'off');
    KW(i,1) = cell2mat(tbl(2,5));
    P(i,1) = p;
    
    tmp2 = [((ZXX(i,:) == 0).*(permute(Z1(1,i,:), [2 3 1]) == 1))';((YXX(i,:) == 0).*(permute(Y1(1,i,:), [2 3 1]) == 1))']; 
    tmp3 = [((ZXX(i,:) == 0).*(permute(Z1(1,i,:), [2 3 1]) == 0))';((YXX(i,:) == 0).*(permute(Y1(1,i,:), [2 3 1]) == 0))']; 
    
    [p, tbl, stats] = kruskalwallis(tmp2, group, 'off');
    KW(i,2) = cell2mat(tbl(2,5));
    P(i,2) = p;
    
    [p, tbl, stats] = kruskalwallis(tmp3, group, 'off');
    KW(i,3) = cell2mat(tbl(2,5));
    P(i,3) = p;
   
end
